@@ -1,5 +1,6 @@
 from rift.ast.calls import CallStacks
 from rift.core.entity import mark
+from rift.core.utils import refresh_context, restrain_context
 from rift.meta.utils import caller_locals
 
 
@@ -9,15 +10,14 @@ class While:
 
     def __enter__(self):
         ctx = caller_locals(back=2)
-        if "self" in ctx and hasattr(ctx["self"], "__refresh__"):
-            ctx["self"].__refresh__()
-        elif "ctx" in ctx and hasattr(ctx["ctx"], "__refresh__"):
-            ctx["ctx"].__refresh__()
+        refresh_context(ctx)
         mark(self.cond)
         self.id = CallStacks.begin_while(self.cond)
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
+        ctx = caller_locals(back=2)
+        restrain_context(ctx)
         CallStacks.end_while(self.id)
 
 
