@@ -1,9 +1,12 @@
+from rift.func.types.types import Cont, Tensor, Tuple
 from rift.types.addr import MsgAddress
+from rift.types.bases import Builder, Cell, Dict, Int, Slice, String
 from rift.types.bool import Bool
 from rift.types.coin import Coin
 from rift.types.constructor import Constructor
 from rift.types.contract_dep import ContractDeployer
 from rift.types.either import Either
+from rift.types.either_ref import EitherRef
 from rift.types.int_aliases import *
 from rift.types.maybe import Maybe
 from rift.types.model import Model
@@ -21,14 +24,3 @@ from rift.types.payload import Payload
 from rift.types.ref import Ref
 from rift.types.sized_int import integer
 from rift.types.slice import slice
-from rift.types.types import (
-    Builder,
-    Cell,
-    Cont,
-    Dict,
-    Int,
-    Slice,
-    String,
-    Tensor,
-    Tuple,
-)
