@@ -1,13 +1,14 @@
 from rift.core import Entity
-from rift.types.types import Builder, Int, Slice
+from rift.types.bases import Builder, Int, Slice
 
 
 class Coin(Int):
     @classmethod
     def __serialize__(cls, to: "Builder", value: "Entity") -> "Builder":
         if isinstance(value, Int) and value.value == 0:
-            b = to.uint(0, 4)
-            return b
+            if hasattr(value, "NAMED") and not value.NAMED:
+                b = to.uint(0, 4)
+                return b
         b = to.coins(value)
         return b
 
